powered_flyby

Function powered_flyby 

pub fn powered_flyby(
    mu_planet: Mu,
    v_inf_in: [f64; 3],
    r_periapsis: Km,
    burn_dv: KmPerSec,
    flyby_plane_normal: [f64; 3],
) -> FlybyResult
Compute a powered flyby (burn at periapsis — Oberth effect).

Same as unpowered flyby but with an added prograde burn at periapsis. The burn increases the periapsis speed, changing both the exit v_inf magnitude and the turn angle.