pub struct RingCrossingAnalysis {
pub crosses_ring_plane: bool,
pub crossing_distance_km: Option<f64>,
pub within_rings: bool,
pub z_offset_at_closest_km: f64,
pub approach_angle_to_ring_plane: Radians,
}Expand description
Result of analyzing whether a transfer trajectory crosses Saturn’s ring plane.
Fields
crosses_ring_plane: boolWhether the trajectory crosses the ring plane
crossing_distance_km: Option<f64>Distance from Saturn at ring plane crossing (km), if crossing occurs
within_rings: boolWhether the crossing occurs within the ring system (ring inner to outer)
z_offset_at_closest_km: f64Z-height above/below Saturn’s equatorial plane at closest approach
approach_angle_to_ring_plane: RadiansAngle between approach velocity and ring plane (radians)