time_dilation_loss

Function time_dilation_loss 

pub fn time_dilation_loss(coordinate_time: Seconds, v: KmPerSec) -> Seconds
Proper time lost due to time dilation at constant velocity.

Returns the difference: coordinate_time - proper_time. This is how much less time passes on the ship compared to an external observer.