pub fn hohmann_phase_angle(departure: Planet, arrival: Planet) -> RadiansExpand description
Required phase angle for a Hohmann transfer between two circular orbits.
The destination planet must be ahead of the departure planet by this angle at the time of departure for the spacecraft to arrive when the destination planet reaches the arrival point.
Returns the phase angle in radians (always positive, measured counter-clockwise from departure to destination).